@@ -1,5 +1,5 @@
 /* Return number of sections in the ELF file.
-   Copyright (C) 2002, 2009 Red Hat, Inc.
+   Copyright (C) 2002, 2009, 2015 Red Hat, Inc.
    This file is part of elfutils.
    Written by Ulrich Drepper <drepper@redhat.com>, 2002.
 
@@ -39,9 +39,8 @@
 
 
 int
-__elf_getshdrnum_rdlock (elf, dst)
-     Elf *elf;
-     size_t *dst;
+internal_function
+__elf_getshdrnum_rdlock (Elf *elf, size_t *dst)
 {
   int result = 0;
   int idx;
@@ -71,9 +70,7 @@ __elf_getshdrnum_rdlock (elf, dst)
 }
 
 int
-elf_getshdrnum (elf, dst)
-     Elf *elf;
-     size_t *dst;
+elf_getshdrnum (Elf *elf, size_t *dst)
 {
   int result;
 
