@@ -20,14 +20,14 @@
 
 tempfiles arextract.test
 
-archive=../libelf/libelf.a
+archive=${abs_top_builddir}/libelf/libelf.a
 if test -f $archive; then
     # The file is really available (i.e., no shared-only built).
     echo -n "Extracting symbols... $ac_c"
 
     # The files we are looking at.
-    for f in ../libelf/*.o; do
-	testrun ./arextract $archive `basename $f` arextract.test || exit 1
+    for f in ${abs_top_builddir}/libelf/*.o; do
+	testrun ${abs_builddir}/arextract $archive `basename $f` arextract.test || exit 1
 	cmp $f arextract.test || {
 	    echo "Extraction of $1 failed"
 	    exit 1
